Crate postcode_extractor

Crate postcode_extractor 

Structs

PostcodeHolder
PostcodeWrapper

Enums

Country
All countries supported by the postcode extractor
PostcodeError

Statics

FIVE_DIGIT_ADDITIONAL_NATIONS
FIVE_DIGIT_NATIONS
Countries which use five digits in the postcode, e.g. 12345
FIVE_DIGIT_WITH_SPACE_NATIONS
Countries which use five digits in the postcode, but there’s a mandatory space, e.g. 653 02
FOUR_DIGIT_NATIONS
Countries which use four digits in the postcode, e.g. 1234
SIX_DIGIT_NATIONS
Countries which use six digits in the postcode, e.g. 123456
UNIQUE_COUNTRIES
Countries which have a unique enough postcode to be identified e.g. UK and the SW17 0QN

Functions

evaluate_all_countries
Will attempt to parse a postcode from an address or a single postcode, and determine which country it comes from.
evaluate_single_country
Used to parse a postcode from an address of an already known country