Structs
Enums
- Country
- All countries supported by the postcode extractor
- Postcode
Error
Statics
- FIVE_
DIGIT_ ADDITIONAL_ NATIONS - FIVE_
DIGIT_ NATIONS - Countries which use five digits in the postcode, e.g.
12345 - FIVE_
DIGIT_ WITH_ SPACE_ NATIONS - Countries which use five digits in the postcode, but there’s a mandatory space, e.g.
653 02 - FOUR_
DIGIT_ NATIONS - Countries which use four digits in the postcode, e.g.
1234 - SIX_
DIGIT_ NATIONS - Countries which use six digits in the postcode, e.g.
123456 - UNIQUE_
COUNTRIES - Countries which have a unique enough postcode to be identified e.g. UK and the SW17 0QN
Functions
- evaluate_
all_ countries - Will attempt to parse a postcode from an address or a single postcode, and determine which country it comes from.
- evaluate_
single_ country - Used to parse a postcode from an address of an already known country